'A reference to the Phidget22.NET.dll must be added to new projects in VB.Net 
'From the "Project" menu select "Add Reference" 
'From the "Add Reference" window select the "Browse" tab 
'Browse to the directory you installed the Phidgets library to 
'The default is "C:\Program Files\Phidgets" 
'Select "Phidget22.NET.dll" and click "OK" 
'To view objects that have been added, select the "View" menu 
'Select "Object Browser" 
'Then expand the Phidget22.NET.dll item 



Imports Phidget22
Imports Phidget22.Events

Public Class Form1
    Dim WithEvents device As Phidget22.RCServo
    Dim open As ExampleUtils.ExampleUtils.CommandLineOpen
    Dim errorBox As ErrorEventBox

    Public Sub New()
        open = New ExampleUtils.ExampleUtils.CommandLineOpen(Me)
        ' This call is required by the Windows Form Designer.
        Phidget22.Phidget.InvokeEventCallbacks = True
        InitializeComponent()
        ' Add any initialization after the InitializeComponent() call.
    End Sub

    Public Sub New(ByVal commandLine As String())
        open = New ExampleUtils.ExampleUtils.CommandLineOpen(Me)
        open.commandLine = commandLine
        Phidget22.Phidget.InvokeEventCallbacks = True
        InitializeComponent()
    End Sub

    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        errorBox = New ErrorEventBox(Me)
        device = New Phidget22.RCServo()

        Dim phidgetParameters As ExampleUtils.commandLineData = open.parseCmdLine()

        Try 'set all the values grabbed from command line.  these values have defaults that are set in ExampleUtils.vb, you can check there to see them
            device.Channel = phidgetParameters.Channel 'selects the channel on the device to open
            device.DeviceSerialNumber = phidgetParameters.SerialNumber 'selects the device or hub to open
            device.HubPort = phidgetParameters.HubPort 'selects th eport on the hub to open
            device.IsHubPortDevice = phidgetParameters.isHubPortDevice 'is the device a port on a vint hub?

            If phidgetParameters.isRemote Then 'are we trying to open a remote device?
                device.IsRemote = True
                Net.EnableServerDiscovery(ServerType.Device) 'turn on network scan
                If phidgetParameters.Password <> vbNullString And phidgetParameters.ServerName <> vbNullString Then
                    Net.SetServerPassword(phidgetParameters.ServerName, phidgetParameters.Password)
                End If
            Else
                device.IsLocal = True
            End If

            device.Open() 'open the device specified by the above parameters
        Catch ex As PhidgetException
            errorBox.addMessage("Error opening the device: " + ex.Message)
        End Try
    End Sub

    Private Sub Form1_FormClosing(ByVal sender As Object, ByVal e As System.Windows.Forms.FormClosingEventArgs) Handles Me.FormClosing
        Application.DoEvents()
        If device.Attached Then
            device.Close()
        End If
    End Sub

    Private Sub device_Attach(ByVal sender As Object, ByVal e As Phidget22.Events.AttachEventArgs) Handles device.Attach
        PhidgetInfoBox1.FillPhidgetInfo(CType(sender, Phidget))

        calibrationBox.Visible = True
        controlsBox.Visible = True
        positionEventTxt.Text = "Unknown"
        velocityEventTxt.Text = "Unknown"
        stoppedchk.Checked = True
        motorDataBox.Visible = True

        initializeController()
    End Sub

    Private Sub initializeController()
        minPWTxt.Text = device.MinPulseWidth.ToString()
        maxPWTxt.Text = device.MaxPulseWidth.ToString()
        minPos.Text = device.MinPosition.ToString()
        maxPos.Text = device.MaxPosition.ToString()


        'ui labels
        positionMinLbl.Text = minPos.Text
        positionMaxLbl.Text = maxPos.Text

        'board config parameters
        Select Case device.DeviceID
            Case DeviceID.PN_1000
                stoppedchk.Visible = False
                speedRampingCheckBox.Visible = False
            Case DeviceID.PN_1001
                stoppedchk.Visible = False
                speedRampingCheckBox.Visible = False
            Case Else
                speedRampingCheckBox.Checked = device.SpeedRampingState
                speedRampingCheckBox.Visible = True
                stoppedchk.Visible = True
        End Select

        enBtn.Text = "Enable"

        Select Case device.DeviceID
            Case DeviceID.PN_1066, DeviceID.PN_1061, DeviceID.PN_1000, DeviceID.PN_1001, DeviceID.PN_RCC1000

        End Select

        Select Case device.DeviceID
            Case DeviceID.PN_1066
            Case DeviceID.PN_1061
            Case DeviceID.PN_RCC1000
                accelPanel.Visible = True
                velocityPanel.Visible = True
                velocityEventTxt.Visible = True
                velocityEventLabel.Visible = True

                velocityMinLbl.Text = device.MinVelocityLimit.ToString("F0")
                velocityMaxLbl.Text = device.MaxVelocityLimit.ToString("F0")
                velocitytrk.Value = CType((device.VelocityLimit / device.MaxVelocityLimit * 1000), Integer)
                velocitytxt.Text = device.VelocityLimit.ToString("F0")

                accelMinLbl.Text = device.MinAcceleration.ToString("F0")
                accelMaxLbl.Text = device.MaxAcceleration.ToString("F0")
                acceltrk.Value = CType(((device.Acceleration - device.MinAcceleration) / (device.MaxAcceleration - device.MinAcceleration) * 1000), Integer)
                acceltxt.Text = device.Acceleration.ToString("F0")
            Case Else
                accelPanel.Visible = False
                velocityPanel.Visible = False
                velocityEventTxt.Visible = False
                velocityEventLabel.Visible = False
        End Select

        Try
            device.TargetPosition = device.MinPosition
            positiontrk.Value = positiontrk.Minimum
            positiontxt.Text = device.MinPosition.ToString("F0")
        Catch ex As Exception
            errorBox.addMessage("Error setting initial positionL " + ex.Message)
        End Try
    End Sub

    Private Sub device_Detach(ByVal sender As Object, ByVal e As Phidget22.Events.DetachEventArgs) Handles device.Detach
        PhidgetInfoBox1.Clear()

        calibrationBox.Visible = False
        controlsBox.Visible = False
        speedRampingCheckBox.Visible = False
        motorDataBox.Visible = False
    End Sub

    Private Sub device_Error(ByVal sender As Object, ByVal e As Phidget22.Events.ErrorEventArgs) Handles device.Error
        errorBox.addMessage(e.Description)
    End Sub

    Private Sub device_Stopperd(ByVal sender As Object, ByVal e As Phidget22.Events.RCServoTargetPositionReachedEventArgs) Handles device.TargetPositionReached
        stoppedchk.Checked = True
    End Sub

    'enable or disable the motor
    Private Sub enBtn_Click(sender As Object, e As EventArgs)
        'toggle enable
        Try
            If device.Engaged = False Then
                device.Engaged = True
                enBtn.Text = "Disable"
            ElseIf device.Engaged = True
                device.Engaged = False
                enBtn.Text = "Enable"
            End If
        Catch ex As Exception
            errorBox.addMessage("Error enabling: " + ex.ToString())
        End Try
    End Sub

    Private Sub positiontrk_Scroll(sender As Object, e As EventArgs)
        'change the target position
        Try
            If device.Engaged Then
                stoppedchk.Checked = False
            End If
        Catch ex As Exception
        End Try

        Try
            device.TargetPosition = CType(positiontrk.Value, Double) / 1000 * (device.MaxPosition - device.MinPosition) + device.MinPosition
            positiontxt.Text = device.TargetPosition.ToString()
        Catch ex As Exception
            errorBox.addMessage("Error setting target position: " + ex.Message)
        End Try
    End Sub

    Private Sub acceltrk_Scroll(sender As Object, e As EventArgs)
        'change the acceleration
        Try
            device.Acceleration = CType(acceltrk.Value, Double) / 1000 * (device.MaxAcceleration - device.MinAcceleration) + device.MinAcceleration
            acceltxt.Text = device.Acceleration.ToString()
        Catch ex As Exception
            errorBox.addMessage("Error setting acceleration: " + ex.Message)
        End Try
    End Sub

    Private Sub velocitytrk_Scroll(sender As Object, e As EventArgs)
        'change the velocity
        Try
            device.VelocityLimit = CType(velocitytrk.Value, Double) / 1000 * device.MaxVelocityLimit
            velocitytxt.Text = device.VelocityLimit.ToString()
        Catch ex As Exception
            errorBox.addMessage("Error setting velocity: " + ex.Message)
        End Try
    End Sub

    Private Sub settingsSET_Click(sender As Object, e As EventArgs) Handles settingsSET.Click
        Try
            'servo calibration parameters
            device.MinPulseWidth = Convert.ToInt32(minPWTxt.Text)
            device.MaxPulseWidth = Convert.ToInt32(maxPWTxt.Text)
            device.MinPosition = Convert.ToDouble(minPos.Text)
            device.MaxPosition = Convert.ToDouble(maxPos.Text)

            If device.Engaged Then
                positiontxt.Text = device.Position.ToString()
            End If

            Select Case device.DeviceID
                Case DeviceID.PN_1066
                Case DeviceID.PN_1061
                Case DeviceID.PN_RCC1000
                    velocitytxt.Text = device.VelocityLimit.ToString()
                    acceltxt.Text = device.Acceleration.ToString()
            End Select
        Catch ex As Exception
            errorBox.addMessage("Error setting parameters: " + ex.Message)
        End Try
    End Sub
End Class



